#!/bin/sh
#repere_espace.tcl
#\
exec wish "$0" ${1+"$@"}
#*************************************************************************
#  Copyright (C) 2002 Eric Seigne <erics@rycks.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#**************************************************************************
#  File  : repere_espace.tcl
#  Author  : andre.connes@toulouse.iufm.fr
#  Modifier: andre.connes@toulouse.iufm.fr
#  Date    : 24/04/2002
#  Licence : GNU/GPL Version 2 ou plus
#
#  Description:
#  ------------
#
#  @version
#  @author     Andre Connes
#  @modifier   Andre Connes
#  @project    Le terrier
#  @copyright  Eric Seigne 24/04/2002
#
#  *************************************************************************
source espace.conf
source msg.tcl
source son_espace.tcl

set bgcolor #ffff80
set bgl #808080
set wsize $WIDTH_SIZE
set hsize $HEIGHT_SIZE
set org 30

wm geometry . +0+0
wm  title . [mc titre]

frame .frame -width $wsize -height $hsize -background $bgl
pack .frame -side top -fill both -expand yes


#############################################################################
# frame en bas avec bouton 'continuer', le score
# et une tiquette de controle de la rponse

frame .bframe -bg $bgcolor
pack .bframe -side bottom -expand true

set bfc .bframe.consigne
button $bfc -font 12x24
grid $bfc -column 1 -row 1

button .bframe.but_droite -image \
  [image create photo fdroite -file [file join images fdroite.gif]]
#grid .bframe.but_droite -column 2  -row 1

  image create photo pbien -file [file join images pbien.gif] 
  image create photo pmal -file [file join images pmal.gif]

# ###############On cre un canvas###########################################
# charg d'accueillir les sorties graphiques,
# qui peuvent tre des images, des textes, des formes gomtriques ...

set c .frame.c
canvas $c -width $wsize -height $hsize -bg $bgcolor -highlightbackground $bgcolor
pack $c -expand true 


#rframe pour les consignes et rsultats
frame .rframe -background $bgcolor -relief raised -bd 3
pack .rframe -side bottom -fill both 

#====================================================================

proc sauver_trace {} {
  global c TRACEDIR tcl_platform user VERSION reponses heure_debut wsize hsize bfc

  #   user=rpertoire+identifiant-lve
  if { $tcl_platform(platform) == "unix" } {
    set user $TRACEDIR/$tcl_platform(user)
  } else {
    set user "$TRACEDIR/leterrier"
  }

  ## trace
  #utilisateur/classe/date/dure/didacticiel/version/liste_des_reponses
  set eleve [lindex [split $user /] end]
  if { $tcl_platform(platform) == "unix" } {
    set heure_fin [clock clicks -milliseconds]
    set duree [expr abs(int($heure_debut-$heure_fin)/1000)]
    set date_heure [clock format [clock seconds] -format "%c"]
    set trace_eleve "$eleve classe \{$date_heure\} $duree espace $VERSION"
  } else {
    set trace_eleve "$eleve classe \{Ddd Mmm  99 00:00:00 9999\} 0 espace $VERSION"
  }
  lappend trace_eleve $reponses

# a sera pour plus tard
#  exec /usr/bin/leterrier_log --message=$trace_eleve --logfile=$user.log
  set f [open [file join $user.log] "a+"]
  puts $f $trace_eleve
  close $f

  #Bilan pour l'lve : nombres de rponses donnes
  $c delete all
  set bgimage [image create photo -file [file join images background.gif]]
  $c create image [expr int($wsize/2)] [expr int($hsize/2) ] -image $bgimage

  $bfc configure -text "[mc Tes_reponses] : $reponses"
  .bframe.but_droite configure -command "exit"
  grid .bframe.but_droite -column 2  -row 1

}

#====================================================================

proc analyse_devant {c i} {
  global bool_devant bool_camion bonne_reponse reponses nbessais bfc pbien pmal

  set nbessais [expr $nbessais + 1]
  if {$bonne_reponse == $i } {
    # afficher en sur-impression l'image bien
    $c create image [$c coords current] -image pbien

    lappend reponses $nbessais
    soundEnter $bfc juste
    $bfc configure -text "[mc Juste] !" -command "soundEnter $bfc juste"
    .bframe.but_droite configure -command "item_droite"
    grid .bframe.but_droite -column 2  -row 1
  } else {
    # afficher en sur-impression l'image faux
    $c create image [$c coords current] -image pmal
    soundEnter $bfc faux 
  }
}

proc item_devant {} {
  global org c bool_devant bool_camion bonne_reponse nbessais bfc

  wm  title . "[mc titre] : [mc titre_devant]"

  set nbessais 0

  #au hasard tester devant ou derrire
  set bool_devant [expr int(rand()*2)]
  # au hasard choisir en premier le camion ou l'auto
  set bool_camion [expr int(rand()*2)]
  if { $bool_devant && $bool_camion } {
    $bfc configure -text [mc camion_devant] \
	-command "soundEnter $bfc camion_devant"
    soundEnter $bfc camion_devant
    set bonne_reponse 1
  }
  if { $bool_devant && !$bool_camion } {
    $bfc configure -text [mc voiture_devant] \
	-command "soundEnter $bfc voiture_devant"
    soundEnter $bfc voiture_devant
    set bonne_reponse 1
  }
  if { ! $bool_devant && $bool_camion } {
    $bfc configure -text [mc voiture_derriere] \
	-command "soundEnter $bfc voiture_derriere"
    soundEnter $bfc voiture_derriere
    set bonne_reponse 2
  }
  if { ! $bool_devant && !$bool_camion } {
    $bfc configure -text [mc camion_derriere] \
	-command "soundEnter $bfc camion_derriere"
    soundEnter $bfc camion_derriere
    set bonne_reponse 2
  }

  set img($bool_camion) [image create photo -file images/camion.gif]
  set img([expr 1 - $bool_camion]) [image create photo -file images/auto.gif]
  set himg [image height $img(1)]
  set wimg [image width $img(1)]

  for { set i 0} {$i < 4} {incr i 1} {
    $c create image \
	[expr $org + int(($i+0.5)*$wimg)] [expr $org + int($himg/2) ] \
	-image $img([expr $i % 2]) -tag img$i
      $c bind img$i <Button-1> "analyse_devant $c $i"
  }
}

#====================================================================

proc analyse_droite {c i} {
  global bool_droite bool_poule bonne_reponse reponses nbessais bfc pbien pmal

  set nbessais [expr $nbessais + 1]
  if {$bonne_reponse == $i } {
    # afficher en sur-impression l'image bien
    $c create image [$c coords current] -image pbien

    lappend reponses $nbessais
    soundEnter $bfc juste
    $bfc configure -text "[mc Juste] !"\
	 -command "soundEnter $bfc juste"
    .bframe.but_droite configure -command "item_entre"
    grid .bframe.but_droite -column 2  -row 1
  } else {
    # afficher en sur-impression l'image faux
    $c create image [$c coords current] -image pmal
    soundEnter $bfc faux 
  }
}

proc item_droite {} {
  global org c bool_droite bool_poule bonne_reponse nbessais bfc

  $c delete all

  wm  title . "[mc titre] : [mc titre_droite]"

  set nbessais 0

  #au hasard tester droite ou gauche
  set bool_droite [expr int(rand()*2)]
  # au hasard choisir en premier le bonhomme de neige ou le hibou
  set bool_poule [expr int(rand()*2)]
  if { $bool_droite && $bool_poule } {
    $bfc configure -text [mc poule_droite] \
	-command "soundEnter $bfc poule_droite"
    soundEnter $bfc poule_droite
    set bonne_reponse 1
  }
  if { $bool_droite && !$bool_poule } {
    $bfc configure -text [mc hibou_droite] \
	-command "soundEnter $bfc hibou_droite"
    soundEnter $bfc hibou_droite
    set bonne_reponse 1
  }
  if { ! $bool_droite && $bool_poule } {
    $bfc configure -text [mc poule_gauche] \
	-command "soundEnter $bfc poule_gauche"
    soundEnter $bfc poule_gauche
    set bonne_reponse 3
  }
  if { ! $bool_droite && !$bool_poule } {
    $bfc configure -text [mc hibou_gauche] \
	-command "soundEnter $bfc hibou_gauche"
    soundEnter $bfc hibou_gauche
    set bonne_reponse 3
  }

  set img($bool_poule) [image create photo -file images/poule.gif]
  set img([expr 1 - $bool_poule]) [image create photo -file images/hibou.gif]
  set himg [image height $img(1)]
  set wimg [image width $img(1)]

  for { set i 1} {$i < 4} {incr i 1} {
    $c create image \
	[expr $org + int(($i+1)*$wimg)] [expr $org + int($himg/2) ] \
	-image $img([expr $i % 2]) -tag img$i
      $c bind img$i <Button-1> "analyse_droite $c $i"
  }
}

#====================================================================

proc analyse_entre {c i} {
  global bool_poele bool_poele_entre bonne_reponse reponses nbessais bfc pbien pmal

  set nbessais [expr $nbessais + 1]
  if {$bonne_reponse == $i } {
    # afficher en sur-impression l'image bien
    $c create image [$c coords current] -image pbien

    lappend reponses $nbessais
    soundEnter $bfc juste
    $bfc configure -text "[mc Juste] !"\
	 -command "soundEnter $bfc juste"
    .bframe.but_droite configure -command "item_a_droite"
    grid .bframe.but_droite -column 2  -row 1
  } else {
    # afficher en sur-impression l'image faux
    $c create image [$c coords current] -image pmal
    soundEnter $bfc faux 
  }
}

proc item_entre {} {
  global org c bool_poele bool_poele_entre bonne_reponse nbessais bfc

  $c delete all

  set nbessais 0

  wm  title . "[mc titre] : [mc titre_entre]"
  # au hasard choisir en premier le poele ou le poisson
  set bool_poele [expr int(rand()*2)]
  # au hasard choisir qui est entre : la poele ou le poisson
  set bool_poele_entre [expr int(rand()*2)]
  if { $bool_poele && $bool_poele_entre} {
    $bfc configure -text [mc poele_entre] \
	-command "soundEnter $bfc poele_entre"
    soundEnter $bfc poele_entre
    set bonne_reponse 1
  }
  if { $bool_poele && ! $bool_poele_entre} {
    $bfc configure -text [mc poisson_entre] \
	-command "soundEnter $bfc poisson_entre"
    soundEnter $bfc poisson_entre
    set bonne_reponse 2
  }
  if { ! $bool_poele && $bool_poele_entre} {
    $bfc configure -text [mc poele_entre] \
	-command "soundEnter $bfc poele_entre"
    soundEnter $bfc poele_entre
    set bonne_reponse 2
  }
  if { ! $bool_poele && ! $bool_poele_entre} {
    $bfc configure -text [mc poisson_entre] \
	-command "soundEnter $bfc poisson_entre"
    soundEnter $bfc poisson_entre
    set bonne_reponse 1
  }

  set img($bool_poele) [image create photo -file images/poele.gif]
  set img([expr 1 - $bool_poele]) [image create photo -file images/poisson.gif]
  set himg [image height $img(1)]
  set wimg [image width $img(1)]

  for { set i 0} {$i < 4} {incr i 1} {
    $c create image \
	[expr $org + int(($i+0.5)*$wimg)] [expr $org + int($himg/2) ] \
	-image $img([expr $i % 2]) -tag img$i
      $c bind img$i <Button-1> "analyse_entre $c $i"
  }
}

#====================================================================

proc analyse_a_droite {c i} {
  global bool_droite bool_nez bonne_reponse reponses nbessais bfc pbien pmal

  set nbessais [expr $nbessais + 1]
  if {$bonne_reponse == $i } {
    # afficher en sur-impression l'image bien
    $c create image [$c coords current] -image pbien

    lappend reponses $nbessais
    soundEnter $bfc juste
    $bfc configure -text "[mc Juste] !"\
	 -command "soundEnter $bfc juste"
    .bframe.but_droite configure -command "item_dessous"
    grid .bframe.but_droite -column 2  -row 1
  } else {
    # afficher en sur-impression l'image faux
    $c create image [$c coords current] -image pmal
    soundEnter $bfc faux 
  }
}

proc item_a_droite {} {
  global org c bool_droite bool_nez bonne_reponse nbessais bfc

  $c delete all

  set nbessais 0

  wm  title . "[mc titre] : [mc titre_a_droite]"
  #au hasard tester droite ou gauche
  set bool_droite [expr int(rand()*2)]
  # au hasard choisir en premier le nez ou l'oeil
  set bool_nez [expr int(rand()*2)]
  if { $bool_droite && $bool_nez } {
    $bfc configure -text [mc nez_droite] \
        -command "soundEnter $bfc nez_droite"
    soundEnter $bfc nez_droite
    set bonne_reponse 3
  }
  if { $bool_droite && !$bool_nez } {
    $bfc configure -text [mc oeil_droite] \
        -command "soundEnter $bfc oeil_droite"
    soundEnter $bfc oeil_droite
    set bonne_reponse 3
  }
  if { ! $bool_droite && $bool_nez } {
    $bfc configure -text [mc nez_gauche] \
        -command "soundEnter $bfc nez_gauche"
    soundEnter $bfc nez_gauche
    set bonne_reponse 1
  }
  if { ! $bool_droite && !$bool_nez } {
    $bfc configure -text [mc oeil_gauche] \
        -command "soundEnter $bfc oeil_gauche"
    soundEnter $bfc oeil_gauche
    set bonne_reponse 1
  }

  set img($bool_nez) [image create photo -file images/nez.gif]
  set img([expr 1 - $bool_nez]) [image create photo -file images/oeil.gif]
  set himg [image height $img(1)]
  set wimg [image width $img(1)]

  for { set i 1} {$i < 4} {incr i 1} {
    $c create image \
	[expr $org + int($i*$wimg)] [expr $org + int($himg/2) ] \
	-image $img([expr $i % 2]) -tag img$i
      $c bind img$i <Button-1> "analyse_a_droite $c $i"
  }
}

#====================================================================

proc analyse_dessous {c i} {
  global bool_dessous bool_ordinateur bonne_reponse reponses nbessais bfc pbien pmal

  set nbessais [expr $nbessais + 1]
  if {$bonne_reponse == $i } {
    # afficher en sur-impression l'image bien
    $c create image [$c coords current] -image pbien

    lappend reponses $nbessais
    soundEnter $bfc juste
    $bfc configure -text "[mc Juste] !"\
	 -command "soundEnter $bfc juste"
    .bframe.but_droite configure -command "sauver_trace"
    grid .bframe.but_droite -column 2  -row 1
  } else {
    # afficher en sur-impression l'image faux
    $c create image [$c coords current] -image pmal
    soundEnter $bfc faux 
  }
}

proc item_dessous {} {
  global org c bool_dessous bool_ordinateur bonne_reponse nbessais bfc

  $c delete all

  set nbessais 0

  wm  title . "[mc titre] : [mc titre_dessous]"
  #au hasard choisir dessous ou dessus
  set bool_dessous [expr int(rand()*2)]
  # au hasard choisir en premier l'ordinateur ou la tlvision
  set bool_ordinateur [expr int(rand()*2)]
  if { $bool_dessous && $bool_ordinateur } {
    $bfc configure -text [mc ordinateur_dessous] \
        -command "soundEnter $bfc ordinateur_dessous"
    soundEnter $bfc ordinateur_dessous
    set bonne_reponse 4
  }
  if { $bool_dessous && ! $bool_ordinateur } {
    $bfc configure -text [mc televiseur_dessous] \
        -command "soundEnter $bfc televiseur_dessous"
    soundEnter $bfc televiseur_dessous
    set bonne_reponse 3
  }
  if { ! $bool_dessous && $bool_ordinateur } {
    $bfc configure -text [mc ordinateur_dessus] \
        -command "soundEnter $bfc ordinateur_dessus"
    soundEnter $bfc ordinateur_dessus 
    set bonne_reponse 0
  }
  if { ! $bool_dessous && ! $bool_ordinateur } {
    $bfc configure -text [mc televiseur_dessus] \
        -command "soundEnter $bfc televiseur_dessus"
    soundEnter $bfc televiseur_dessus
    set bonne_reponse 1
  }

  set img($bool_ordinateur) [image create photo -file images/ordinateur.gif]
  set img([expr 1 - $bool_ordinateur]) [image create photo -file images/television.gif]
  set himg [image height $img(1)]
  set wimg [image width $img(1)]

  #ligne dessus
    $c create image \
	[expr $org + int(1*$wimg)] [expr $org + int($himg/2) ] \
	-image $img($bool_ordinateur) -tag img0
      $c bind img0 <Button-1> "analyse_dessous $c 0"
    $c create image \
	[expr $org + int(2*$wimg)] [expr $org + int($himg/2) ] \
	-image $img([expr 1 - $bool_ordinateur]) -tag img1
      $c bind img1 <Button-1> "analyse_dessous $c 1"
    $c create image \
	[expr $org + int(3*$wimg)] [expr $org + int($himg/2) ] \
	-image $img($bool_ordinateur) -tag img2
      $c bind img2 <Button-1> "analyse_dessous $c 2"
  #ligne dessous
    $c create image \
	[expr $org + int(1*$wimg)] [expr $org + int(1.5*$himg) ] \
	-image $img([expr 1 - $bool_ordinateur]) -tag img3
      $c bind img3 <Button-1> "analyse_dessous $c 3"
    $c create image \
	[expr $org + int(2*$wimg)] [expr $org + int(1.5*$himg) ] \
	-image $img($bool_ordinateur) -tag img4
      $c bind img4 <Button-1> "analyse_dessous $c 4"
    $c create image \
	[expr $org + int(3*$wimg)] [expr $org + int(1.5*$himg) ] \
	-image $img($bool_ordinateur) -tag img5
      $c bind img5 <Button-1> "analyse_dessous $c 5"
}

#====================================================================

# gestion du temps : heure du dbut de l'exercice
  if { $tcl_platform(platform) == "unix" } {
    set heure_debut [clock clicks -milliseconds]
  } else {
    set heure_debut 0
  }

#gestion de la trace : vide au dbut
  set reponses ""

item_devant
#item_droite
#item_entre
#item_a_droite
#item_dessous
